@@ -72,7 +72,7 @@ class TestEventTypes(unittest.TestCase):
         self.assertEqual(inst.pid, 2)
         self.assertEqual(inst.data, 3)
 
-    def test_ProcessLogEvent_inheritence(self):
+    def test_ProcessLogEvent_inheritance(self):
         from supervisor.events import ProcessLogEvent
         from supervisor.events import Event
         self.assertTrue(
@@ -87,7 +87,7 @@ class TestEventTypes(unittest.TestCase):
         self.assertEqual(inst.data, 3)
         self.assertEqual(inst.channel, 'stdout')
 
-    def test_ProcessLogStdoutEvent_inheritence(self):
+    def test_ProcessLogStdoutEvent_inheritance(self):
         from supervisor.events import ProcessLogStdoutEvent
         from supervisor.events import ProcessLogEvent
         self.assertTrue(
@@ -102,7 +102,7 @@ class TestEventTypes(unittest.TestCase):
         self.assertEqual(inst.data, 3)
         self.assertEqual(inst.channel, 'stderr')
 
-    def test_ProcessLogStderrEvent_inheritence(self):
+    def test_ProcessLogStderrEvent_inheritance(self):
         from supervisor.events import ProcessLogStderrEvent
         from supervisor.events import ProcessLogEvent
         self.assertTrue(
@@ -116,7 +116,7 @@ class TestEventTypes(unittest.TestCase):
         self.assertEqual(inst.pid, 2)
         self.assertEqual(inst.data, 3)
 
-    def test_ProcessCommunicationEvent_inheritence(self):
+    def test_ProcessCommunicationEvent_inheritance(self):
         from supervisor.events import ProcessCommunicationEvent
         from supervisor.events import Event
         self.assertTrue(
@@ -131,7 +131,7 @@ class TestEventTypes(unittest.TestCase):
         self.assertEqual(inst.data, 3)
         self.assertEqual(inst.channel, 'stdout')
 
-    def test_ProcessCommunicationStdoutEvent_inheritence(self):
+    def test_ProcessCommunicationStdoutEvent_inheritance(self):
         from supervisor.events import ProcessCommunicationStdoutEvent
         from supervisor.events import ProcessCommunicationEvent
         self.assertTrue(
@@ -147,7 +147,7 @@ class TestEventTypes(unittest.TestCase):
         self.assertEqual(inst.data, 3)
         self.assertEqual(inst.channel, 'stderr')
 
-    def test_ProcessCommunicationStderrEvent_inheritence(self):
+    def test_ProcessCommunicationStderrEvent_inheritance(self):
         from supervisor.events import ProcessCommunicationStderrEvent
         from supervisor.events import ProcessCommunicationEvent
         self.assertTrue(
@@ -161,7 +161,7 @@ class TestEventTypes(unittest.TestCase):
         self.assertEqual(inst.type, 1)
         self.assertEqual(inst.data, 2)
 
-    def test_RemoteCommunicationEvent_inheritence(self):
+    def test_RemoteCommunicationEvent_inheritance(self):
         from supervisor.events import RemoteCommunicationEvent
         from supervisor.events import Event
         self.assertTrue(
@@ -279,7 +279,7 @@ class TestSerializations(unittest.TestCase):
             config = pconfig1
         process1.group = DummyGroup
         event = ProcessLogStdoutEvent(process1, 1, 'yo')
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(headers['processname'], 'process1', headers)
         self.assertEqual(headers['groupname'], 'process1', headers)
         self.assertEqual(headers['pid'], '1', headers)
@@ -294,7 +294,7 @@ class TestSerializations(unittest.TestCase):
             config = pconfig1
         process1.group = DummyGroup
         event = ProcessLogStderrEvent(process1, 1, 'yo')
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(headers['processname'], 'process1', headers)
         self.assertEqual(headers['groupname'], 'process1', headers)
         self.assertEqual(headers['pid'], '1', headers)
@@ -309,7 +309,7 @@ class TestSerializations(unittest.TestCase):
             config = pconfig1
         process1.group = DummyGroup
         event = ProcessCommunicationStdoutEvent(process1, 1, 'yo')
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(headers['processname'], 'process1', headers)
         self.assertEqual(headers['groupname'], 'process1', headers)
         self.assertEqual(headers['pid'], '1', headers)
@@ -324,7 +324,7 @@ class TestSerializations(unittest.TestCase):
         process1.group = DummyGroup
         from supervisor.events import ProcessCommunicationStderrEvent
         event = ProcessCommunicationStderrEvent(process1, 1, 'yo')
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(headers['processname'], 'process1', headers)
         self.assertEqual(headers['groupname'], 'process1', headers)
         self.assertEqual(headers['pid'], '1', headers)
@@ -333,21 +333,21 @@ class TestSerializations(unittest.TestCase):
     def test_remote_comm_event(self):
         from supervisor.events import RemoteCommunicationEvent
         event = RemoteCommunicationEvent('foo', 'bar')
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(headers['type'], 'foo', headers)
         self.assertEqual(payload, 'bar')
 
     def test_process_group_added_event(self):
         from supervisor.events import ProcessGroupAddedEvent
         event = ProcessGroupAddedEvent('foo')
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(headers['groupname'], 'foo')
         self.assertEqual(payload, '')
 
     def test_process_group_removed_event(self):
         from supervisor.events import ProcessGroupRemovedEvent
         event = ProcessGroupRemovedEvent('foo')
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(headers['groupname'], 'foo')
         self.assertEqual(payload, '')
 
@@ -366,7 +366,7 @@ class TestSerializations(unittest.TestCase):
             process1 = DummyProcess(pconfig1)
             process1.group = DummyGroup
             event = klass(process1, ProcessStates.STARTING)
-            headers, payload = self._deserialize(str(event))
+            headers, payload = self._deserialize(event.payload())
             self.assertEqual(len(headers), 3)
             self.assertEqual(headers['processname'], 'process1')
             self.assertEqual(headers['groupname'], 'process1')
@@ -390,7 +390,7 @@ class TestSerializations(unittest.TestCase):
             process1.group = DummyGroup
             process1.pid = 1
             event = klass(process1, ProcessStates.STARTING)
-            headers, payload = self._deserialize(str(event))
+            headers, payload = self._deserialize(event.payload())
             self.assertEqual(len(headers), 4)
             self.assertEqual(headers['processname'], 'process1')
             self.assertEqual(headers['groupname'], 'process1')
@@ -413,7 +413,7 @@ class TestSerializations(unittest.TestCase):
             process1 = DummyProcess(pconfig1)
             process1.group = DummyGroup
             event = klass(process1, ProcessStates.STARTING)
-            headers, payload = self._deserialize(str(event))
+            headers, payload = self._deserialize(event.payload())
             self.assertEqual(len(headers), 4)
             self.assertEqual(headers['processname'], 'process1')
             self.assertEqual(headers['groupname'], 'process1')
@@ -422,11 +422,11 @@ class TestSerializations(unittest.TestCase):
             self.assertEqual(payload, '')
             process1.backoff = 1
             event = klass(process1, ProcessStates.STARTING)
-            headers, payload = self._deserialize(str(event))
+            headers, payload = self._deserialize(event.payload())
             self.assertEqual(headers['tries'], '1')
             process1.backoff = 2
             event = klass(process1, ProcessStates.STARTING)
-            headers, payload = self._deserialize(str(event))
+            headers, payload = self._deserialize(event.payload())
             self.assertEqual(headers['tries'], '2')
 
     def test_process_state_exited_event_expected(self):
@@ -442,7 +442,7 @@ class TestSerializations(unittest.TestCase):
         event = events.ProcessStateExitedEvent(process1,
                                                ProcessStates.STARTING,
                                                expected=True)
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(len(headers), 5)
         self.assertEqual(headers['processname'], 'process1')
         self.assertEqual(headers['groupname'], 'process1')
@@ -464,7 +464,7 @@ class TestSerializations(unittest.TestCase):
         event = events.ProcessStateExitedEvent(process1,
                                                ProcessStates.STARTING,
                                                expected=False)
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(len(headers), 5)
         self.assertEqual(headers['processname'], 'process1')
         self.assertEqual(headers['groupname'], 'process1')
@@ -476,7 +476,7 @@ class TestSerializations(unittest.TestCase):
     def test_supervisor_sc_event(self):
         from supervisor import events
         event = events.SupervisorRunningEvent()
-        headers, payload = self._deserialize(str(event))
+        headers, payload = self._deserialize(event.payload())
         self.assertEqual(headers, {})
         self.assertEqual(payload, '')
 
@@ -488,7 +488,7 @@ class TestSerializations(unittest.TestCase):
             events.Tick3600Event,
             ):
             event = klass(1, 2)
-            headers, payload = self._deserialize(str(event))
+            headers, payload = self._deserialize(event.payload())
             self.assertEqual(headers, {'when':'1'})
             self.assertEqual(payload, '')
 
